## v0.1.2 (2024-02-19)

## v0.1.1 (2024-02-19)

### Fix

- use `min` instead of deprecated `T` for pandas freq
- reduce required matplotlib version for python 3.7 compatibility
- TimeSeriesSplit now works with newer pandas versions


- update project repository urls
- Update the readme with new project url
